## MEFrpLib

<p align="right">based on ME Frp API<br>presented by LxHTT</p>

这是一个封装了ME Frp API的Python库。

### 安装

___

```bash
pip install MEFrpLib
```

### 开始使用  

___

#### 导入  

```python

from MEFrpLib import (
    me_get_user_info,
    me_user_get_sign_info,
    me_user_sign,
    me_refresh_user_token,
    me_get_realname_status,
    me_post_realname,
    me_get_tunnel_list,
    me_get_tunnel_config_node,
    me_get_tunnel_config_id,
    me_create_tunnel,
    me_delete_tunnel,
    me_get_tunnel_info,
    me_node_list,
    me_get_free_port,
    me_login,
    me_get_sponsor,
    me_get_statistics,
    me_register,
    me_send_register_email,
    me_forgot_password,
    me_get_setting,
)

```
